﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Diagnostics;
using System.Globalization;
using System.Reflection;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.ServiceModel.Web;
using System.Text;
using System.Threading;
using System.Web;
using Seven.Integrations.Orbe.Business;
using Seven.Integrations.Orbe.Globals;
using Seven.Integrations.Orbe.Objects;
using Seven.Integrations.Orbe.Printing;
using Newtonsoft.Json;

namespace Seven.Integrations.Orbe
{
    [ServiceContract(Namespace = "SevenIPMWS")]
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    public class Maestro
    {
        #region Seguridad

        [WebGet]
        [OperationContract]
        public string GetDatosCombo(int IdJuego, string LangCode)
        {
            try
            {
                return HTMLSelects.Datos(IdJuego);
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region EXTERNAL Log Sheet

        [WebGet]
        [OperationContract]
        public string GetLogSheet(string Inicio, string Final, int Pagina, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    DateTime S = DateTime.Today;
                    try
                    {
                        //S = DateParser.GetDate(Inicio);
                        S = DateTime.Parse(Inicio, ciLocal);
                    }
                    catch (Exception) { }
                    DateTime F = DateTime.Today;
                    try
                    {
                        //F = DateParser.GetDate(Final);
                        F = DateTime.Parse(Final, ciLocal);
                    }
                    catch (Exception) { }
                    return Tablas.LogSheet(S, F, Pagina, iden)
                        .Replace("Página", L.LBL("LblGENPage"))
                        .Replace("LblGENDate", L.LBL("LblGENDate"))
                        .Replace("LblGENObservations", L.LBL("LblGENObservations"))
                        .Replace("LblGENPermit", L.LBL("LblGENPermit"));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\">" + L.LBL("LblGENWrongQuery") + "</br> " + Memoria.Error + "\n" + ex.Message + Inicio + "F" + Final + Pagina + "</p>";
            }
        }

        #endregion

        #region Sistema

        [WebGet]
        [OperationContract]
        public string GetAccordionForm(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    string Dir = "src=\"";

                    if (SubDir == 1)
                    {
                        Dir = "src=\"../";
                    }

                    return ("<div id=\"SevenMenu\">\n" +
                                Logica.GetAccordion(1, iden.U, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                            "</div>\n" +
                            "<table width=\"100%\">\n" +
                                "<tr>\n" +
                                    "<td width=\"50%\">\n" +
                                        "<button type=\"submit\" style=\"width: 100%;\">" +
                                            "<table>" +
                                                "<tr>" +
                                                    "<td><img src=\"img/disk.png\" /></td>" +
                                                    "<td><span style=\"font-size: 8pt;\">LblGENSave</span></td>" +
                                                "</tr>" +
                                            "</table>" +
                                        "</button>" +
                                    "</td>\n" +
                                    "<td width=\"50%\">\n" +
                                        "<button type=\"button\" onclick=\"mostrarAjaxAccordion();\" style=\"width: 100%;\">" +
                                            "<table>" +
                                                "<tr>" +
                                                    "<td><img src=\"img/arrow-return-180-left.png\" /></td>" +
                                                    "<td><span style=\"font-size: 8pt;\">LblGENCancel</span></td>" +
                                                "</tr>" +
                                            "</table>" +
                                        "</button>" +
                                    "</td>\n" +
                                "</tr>\n" +
                            "</table>\n")
                            .Replace("LblGENSave", L.LBL("LblGENSave"))
                            .Replace("LblGENCancel", L.LBL("LblGENCancel"))
                            .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetAccordion(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    string Dir = "src=\"";

                    if (SubDir == 1)
                    {
                        Dir = "src=\"../";
                    }

                    return ("<div id=\"SevenMenu\">\n" +
                                Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                            "</div>\n" +
                            "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                                "<table>" +
                                    "<tr>" +
                                        "<td><img src=\"img/user.png\" /></td>" +
                                        "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                                    "</tr>" +
                                "</table>" +
                            "</button>")
                            .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                            .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        [WebGet]
        [OperationContract]
        public string Book(string R, string I)
        {
            Thread.CurrentThread.CurrentUICulture = CultureInfo.GetCultureInfo("en-US");
            Thread.CurrentThread.CurrentCulture = CultureInfo.CreateSpecificCulture("en-US");

            int nivel = 0;
            int id_json = 0;
            int id_rese = 0;
            int nro_reserva = 0;
            string resultado = "Registrada";
            bool error = false;

            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {

                    #region Nivel 1 - Guardar el Objeto JSON

                    nivel = 1;

                    if (string.IsNullOrEmpty(R))
                    {
                        throw new Exception("El parámetro R es nulo o no tiene caracteres");
                    }

                    id_json = Logica.PutOrbeJSON(new OrbeJSON(0, DateTime.Now, HttpContext.Current.Request.UserHostAddress, R, false));

                    #endregion

                    #region Nivel 2 - Deserializar el Objeto JSON

                    nivel = 2;

                    OrbeReserva reserva = JsonConvert.DeserializeObject<OrbeReserva>(R);

                    #endregion

                    #region Nivel 3 - Transformar la Información

                    nivel = 3;

                    id_rese = Logica.PutReserva(reserva, id_json);

                    #endregion

                    #region Nivel 4 - Enviar la Reserva

                    nivel = 4;

                    nro_reserva = Logica.SendReserva(id_rese);

                    #endregion
                }
                else
                {
                    throw new Exception("LblGENLinkNotFound");
                }
            }
            catch (Exception ex)
            {
                error = true;
                resultado = L.ERR(ex.Message).Replace("[", "").Replace("]", "");
            }

            try
            {
                #region Registrar en la Bitácora

                BitacoraReserva log = new BitacoraReserva();
                log.id_logr = 0;
                log.id_json = id_json;
                log.id_rese = id_rese;
                log.id_rese_fdk = 0;
                log.nro_reserva = nro_reserva;
                log.nivel = nivel;
                log.fecha = DateTime.Now;
                log.descripcion = CrazyGenie.JSONPurifier(resultado);
                log.error = error;
                log.IP = HttpContext.Current.Request.UserHostAddress;

                Logica.PutBitacoraReservas(log);

                if (error)
                {
                    resultado = "Error";
                }

                #endregion
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                resultado = "Alerta";
            }

            Resultado res = new Resultado();
            res.nro_reserva = nro_reserva;
            res.resultado = resultado.ToLower();

            //return "{\"nro_reserva\": " + nro_reserva + ", \"estado\": \"" + resultado.ToLower() + "\"}"; 
            return JsonConvert.SerializeObject(res, Formatting.None);
        }
    }
}

